==> nextcloud-18.0.4.tgz: nextcloud/apps/survey_client/l10n/de_DE.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Letzter Bericht gesendet am: {on}",
    "An error occurred while sending your report." : "Es ist ein Fehler beim Senden des Berichtes aufgetreten.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "App-Liste <em>(Zu jeder App: Name, Version, ist aktiviert?)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Datenbank <em>(Typ, Version, Datenbankgröße)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Verschlüsselungsinformation <em>(Ist aktiviert?, Welches ist das Standard-Modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Anzahl an Freigaben <em>(Pro Typ und Berechtigung)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-Umgebung <em>(Version, Speichergrenze, Max. Ausführungszeit, Max. Dateigröße)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Details zur Serverinstanz <em>(Version, Wird Memcache verwendet?, Sind Sperren/Vorschau/Avatare aktiviert?)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statistik <em>(Anzahl von: Dateien, Benutzern, Speicher pro Typ, Kommentare und Schlagworte)</em>",
    "Usage survey" : "Nutzungsbericht",
    "Help improve Nextcloud" : "Helfen Sie Nextcloud zu verbessern",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Möchten Sie uns helfen Nextcloud zu verbessern? Das können Sie durch die Übertragen anonymisierter Daten Ihrer Einstellungen und Nutzung. Sie können dies jederzeit in den Administrationseinstellungen deaktivieren.",
    "Not now" : "Nicht jetzt",
    "Send usage" : "Nutzungsbericht senden",
    "Never" : "Niemals",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Sendet anonymisierte Daten an Nextcloud, damit wir Nextcloud noch besser machen können.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Sendet anonymisierte Daten an Nextcloud, damit wir Nextcloud noch besser machen können. Sie\n         haben jederzeit volle Kontrolle über die an Nextcloud gesendeten Daten. \n          Jederzeit abschaltbar.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Sie können uns helfen Nextcloud zu verbessern. Senden Sie uns Daten von Ihren Einstellungen und Nutzung.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Wir nehmen Ihren Datenschutz sehr ernst. Das Senden der Daten ist standardmäßig deaktiviert. Wenn Sie das Senden aktivieren, so sind Ihre Daten anonymisiert und Sie entscheiden welche Informationen Sie uns senden. Sobald Sie uns einen Bericht senden, wird der vorherige Bericht gelöscht. Senden Sie uns einen leeren Bericht um all Ihre Informationen auf unseren Servern zu löschen.",
    "Send new report now" : "Neuen Bericht jetzt senden",
    "Send usage survey monthly" : "Nutzungsbericht monatlich senden",
    "Data to send" : "Zu sendende Daten",
    "Last report sent on: %s" : "Letzter Bericht gesendet am: %s",
    "Last report" : "Letzter Bericht"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.4.tgz: nextcloud/apps/survey_client/l10n/de_DE.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Letzter Bericht gesendet am: {on}",
    "An error occurred while sending your report." : "Es ist ein Fehler beim Senden des Berichtes aufgetreten.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "App-Liste <em>(Zu jeder App: Name, Version, ist aktiviert?)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Datenbank <em>(Typ, Version, Datenbankgröße)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Verschlüsselungsinformation <em>(Ist aktiviert?, Welches ist das Standard-Modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Anzahl an Freigaben <em>(Pro Typ und Berechtigung)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-Umgebung <em>(Version, Speichergrenze, Max. Ausführungszeit, Max. Dateigröße)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Details zur Serverinstanz <em>(Version, Wird Memcache verwendet?, Sind Sperren/Vorschau/Avatare aktiviert?)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statistik <em>(Anzahl von: Dateien, Benutzern, Speicher pro Typ, Kommentare und Schlagworte)</em>",
    "Usage survey" : "Nutzungsbericht",
    "Help improve Nextcloud" : "Helfen Sie Nextcloud zu verbessern",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Möchten Sie uns helfen Nextcloud zu verbessern? Das können Sie durch die Übertragen anonymisierter Daten Ihrer Einstellungen und Nutzung. Sie können dies jederzeit in den Administrationseinstellungen deaktivieren.",
    "Not now" : "Nicht jetzt",
    "Send usage" : "Nutzungsbericht senden",
    "Never" : "Niemals",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Sendet anonymisierte Daten an Nextcloud, damit wir Nextcloud noch besser machen können.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Sendet anonymisierte Daten an Nextcloud, damit wir Nextcloud noch besser machen können. Sie\n         haben jederzeit volle Kontrolle über die an Nextcloud gesendeten Daten. \n          Jederzeit abschaltbar.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Sie können uns helfen Nextcloud zu verbessern. Senden Sie uns Daten über Ihre Einstellungen und Ihre Nutzung.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Wir nehmen den Schutz Ihrer Daten sehr ernst. Das Senden der Daten ist standardmäßig deaktiviert. Wenn Sie das Senden aktivieren, so sind Ihre Daten anonymisiert und Sie entscheiden welche Informationen Sie uns senden. Sobald Sie uns einen Bericht senden, wird der vorherige Bericht gelöscht. Senden Sie uns einen leeren Bericht um all Ihre Informationen auf unseren Servern zu löschen.",
    "Send new report now" : "Neuen Bericht jetzt senden",
    "Send usage survey monthly" : "Nutzungsbericht monatlich senden",
    "Data to send" : "Zu sendende Daten",
    "Last report sent on: %s" : "Letzter Bericht gesendet am: %s",
    "Last report" : "Letzter Bericht"
},
"nplurals=2; plural=(n != 1);");
